==> v21.04.tar.gz: bookstack/resources/lang/fr/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Annuler',
    'confirm' => 'Confirmer',
    'back' => 'Retour',
    'save' => 'Enregistrer',
    'continue' => 'Continuer',
    'select' => 'Sélectionner',
    'toggle_all' => 'Tout sélectionner',
    'more' => 'Montrer plus',

    // Form Labels
    'name' => 'Nom',
    'description' => 'Description',
    'role' => 'Rôle',
    'cover_image' => 'Image de couverture',
    'cover_image_description' => 'Cette image doit faire environ 440x250 px.',
    
    // Actions
    'actions' => 'Actions',
    'view' => 'Voir',
    'view_all' => 'Tout afficher',
    'create' => 'Créer',
    'update' => 'Modifier',
    'edit' => 'Editer',
    'sort' => 'Trier',
    'move' => 'Déplacer',
    'copy' => 'Copier',
    'reply' => 'Répondre',
    'delete' => 'Supprimer',
    'delete_confirm' => 'Confirmer la suppression',
    'search' => 'Chercher',
    'search_clear' => 'Réinitialiser la recherche',
    'reset' => 'Réinitialiser',
    'remove' => 'Enlever',
    'add' => 'Ajouter',
    'fullscreen' => 'Plein écran',

    // Sort Options
    'sort_options' => 'Options de tri',
    'sort_direction_toggle' => 'Inverser la direction du tri',
    'sort_ascending' => 'Tri ascendant',
    'sort_descending' => 'Tri descendant',
    'sort_name' => 'Nom',
    'sort_default' => 'Default',
    'sort_created_at' => 'Date de création',
    'sort_updated_at' => 'Date de mise à jour',

    // Misc
    'deleted_user' => 'Utilisateur supprimé',
    'no_activity' => 'Aucune activité',
    'no_items' => 'Aucun élément',
    'back_to_top' => 'Retour en haut',
    'toggle_details' => 'Afficher les détails',
    'toggle_thumbnails' => 'Afficher les vignettes',
    'details' => 'Détails',
    'grid_view' => 'Vue en grille',
    'list_view' => 'Vue en liste',
    'default' => 'Défaut',
    'breadcrumb' => 'Fil d\'Ariane',

    // Header
    'profile_menu' => 'Menu du profil',
    'view_profile' => 'Voir le profil',
    'edit_profile' => 'Modifier le profil',
    'dark_mode' => 'Mode sombre',
    'light_mode' => 'Mode clair',

    // Layout tabs
    'tab_info' => 'Informations',
    'tab_content' => 'Contenu',

    // Email Content
    'email_action_help' => 'Si vous rencontrez des problèmes pour cliquer sur le bouton ":actionText", copiez et collez l\'adresse ci-dessous dans votre navigateur :',
    'email_rights' => 'Tous droits réservés',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Politique de confidentialité',
    'terms_of_service' => 'Conditions d\'utilisation',
];

==> v21.05.tar.gz: bookstack/resources/lang/fr/common.php <==
<?php
/**
 * Common elements found throughout many areas of BookStack.
 */
return [

    // Buttons
    'cancel' => 'Annuler',
    'confirm' => 'Confirmer',
    'back' => 'Retour',
    'save' => 'Enregistrer',
    'continue' => 'Continuer',
    'select' => 'Sélectionner',
    'toggle_all' => 'Tout sélectionner',
    'more' => 'Montrer plus',

    // Form Labels
    'name' => 'Nom',
    'description' => 'Description',
    'role' => 'Rôle',
    'cover_image' => 'Image de couverture',
    'cover_image_description' => 'Cette image doit faire environ 440x250 px.',
    
    // Actions
    'actions' => 'Actions',
    'view' => 'Voir',
    'view_all' => 'Tout afficher',
    'create' => 'Créer',
    'update' => 'Modifier',
    'edit' => 'Editer',
    'sort' => 'Trier',
    'move' => 'Déplacer',
    'copy' => 'Copier',
    'reply' => 'Répondre',
    'delete' => 'Supprimer',
    'delete_confirm' => 'Confirmer la suppression',
    'search' => 'Chercher',
    'search_clear' => 'Réinitialiser la recherche',
    'reset' => 'Réinitialiser',
    'remove' => 'Enlever',
    'add' => 'Ajouter',
    'fullscreen' => 'Plein écran',
    'favourite' => 'Favoris',
    'unfavourite' => 'Supprimer des favoris',
    'next' => 'Next',
    'previous' => 'Previous',

    // Sort Options
    'sort_options' => 'Options de tri',
    'sort_direction_toggle' => 'Inverser la direction du tri',
    'sort_ascending' => 'Tri ascendant',
    'sort_descending' => 'Tri descendant',
    'sort_name' => 'Nom',
    'sort_default' => 'Défaut',
    'sort_created_at' => 'Date de création',
    'sort_updated_at' => 'Date de mise à jour',

    // Misc
    'deleted_user' => 'Utilisateur supprimé',
    'no_activity' => 'Aucune activité',
    'no_items' => 'Aucun élément',
    'back_to_top' => 'Retour en haut',
    'toggle_details' => 'Afficher les détails',
    'toggle_thumbnails' => 'Afficher les vignettes',
    'details' => 'Détails',
    'grid_view' => 'Vue en grille',
    'list_view' => 'Vue en liste',
    'default' => 'Défaut',
    'breadcrumb' => 'Fil d\'Ariane',

    // Header
    'header_menu_expand' => 'Développer le menu',
    'profile_menu' => 'Menu du profil',
    'view_profile' => 'Voir le profil',
    'edit_profile' => 'Modifier le profil',
    'dark_mode' => 'Mode sombre',
    'light_mode' => 'Mode clair',

    // Layout tabs
    'tab_info' => 'Informations',
    'tab_info_label' => 'Onglet : Afficher les informations secondaires',
    'tab_content' => 'Contenu',
    'tab_content_label' => 'Onglet : Afficher le contenu principal',

    // Email Content
    'email_action_help' => 'Si vous rencontrez des problèmes pour cliquer sur le bouton ":actionText", copiez et collez l\'adresse ci-dessous dans votre navigateur :',
    'email_rights' => 'Tous droits réservés',

    // Footer Link Options
    // Not directly used but available for convenience to users.
    'privacy_policy' => 'Politique de confidentialité',
    'terms_of_service' => 'Conditions d\'utilisation',
];
